@@ -1,6 +1,6 @@
 import ast
 from collections import namedtuple
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, Optional
 
 
 def is_module_function_call(node: ast.Call, module: str, function: str) -> bool:
@@ -10,6 +10,11 @@ def is_module_function_call(node: ast.Call, module: str, function: str) -> bool:
         return False
 
 
+ParseResult = namedtuple(
+    "ParseResult", ["step", "parameters", "inputs", "image", "environment"]
+)
+
+
 class PrepareParser(ast.NodeVisitor):
     """Parses .py file for Valohai inputs, parameters, step name
 
@@ -39,10 +44,11 @@ class PrepareParser(ast.NodeVisitor):
         valohai.prepare(parameters=get_parameters())
     """
 
-    assignments: Dict[str, Any]  # TODO: embetter type
-    parameters: Dict[str, Any]  # TODO: embetter type
-    inputs: Dict[str, Any]  # TODO: embetter type
+    assignments: Dict[str, Any]
+    parameters: Dict[str, Any]
+    inputs: Dict[str, Any]
     step: Optional[str]
+    environment: Optional[str]
 
     def __init__(self) -> None:
         self.assignments = {}
@@ -50,6 +56,7 @@ class PrepareParser(ast.NodeVisitor):
         self.inputs = {}
         self.step = None
         self.image = None
+        self.environment = None
 
     def visit_Assign(self, node: ast.Assign) -> None:
         try:
@@ -74,38 +81,31 @@ class PrepareParser(ast.NodeVisitor):
                     self.step = ast.literal_eval(key.value)
                 elif key.arg == "image":
                     self.image = ast.literal_eval(key.value)
+                elif key.arg == "environment":
+                    self.environment = ast.literal_eval(key.value)
+
+    def _process_kwarg(self, key: ast.keyword, *, error_hint: str = "") -> Any:
+        if isinstance(key.value, ast.Name) and key.value.id in self.assignments:
+            return self.assignments[key.value.id]
+        if isinstance(key.value, ast.Dict):
+            return ast.literal_eval(key.value)
+        raise NotImplementedError(f"Unable to parse {error_hint}: {key.value!r}")
 
     def process_default_inputs_arg(self, key: ast.keyword) -> None:
-        if isinstance(key.value, ast.Name) and key.value.id in self.assignments:
-            self.inputs = {
-                key: value if isinstance(value, List) else [value]
-                for key, value in self.assignments[key.value.id].items()
-            }
-        elif isinstance(key.value, ast.Dict):
-            self.inputs = {
-                key: value if isinstance(value, List) else [value]
-                for key, value in ast.literal_eval(key.value).items()
-            }
-        else:
-            raise NotImplementedError()
+        self.inputs = self._process_kwarg(key, error_hint="inputs=")
 
     def process_default_parameters_arg(self, key: ast.keyword) -> None:
-        if isinstance(key.value, ast.Name) and key.value.id in self.assignments:
-            self.parameters = self.assignments[key.value.id]
-        elif isinstance(key.value, ast.Dict):
-            self.parameters = ast.literal_eval(key.value)
-        else:
-            raise NotImplementedError()
+        self.parameters = self._process_kwarg(key, error_hint="parameters=")
 
 
-def parse(source):
+def parse(source: str) -> ParseResult:
     tree = ast.parse(source)
     parser = PrepareParser()
     parser.visit(tree)
-    result = namedtuple("result", ["step", "parameters", "inputs", "image"])
-    return result(
+    return ParseResult(
         step=parser.step,
         parameters=parser.parameters,
         inputs=parser.inputs,
         image=parser.image,
+        environment=parser.environment,
     )
